==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPanePinnedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDetailDescription } from "./WebPanePinnedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPanePinnedEventArgsDetailDescriptionMetadata, _super);
    function WebPanePinnedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPanePinnedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPanePinnedEventArgsDetailDescriptionMetadata.a == null) {
            WebPanePinnedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPanePinnedEventArgsDetailDescriptionMetadata.c(WebPanePinnedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPanePinnedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPanePinnedEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PanePinnedEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebContentPane");
        a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
        a.item("NewValue", "Boolean");
        a.item("Location", "ExportedType:string:UnpinnedLocation");
        a.item("Location@stringUnion", "WebComponents;React");
        a.item("Location@names", "Top;Bottom;Left;Right");
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPanePinnedEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebPanePinnedEventArgsDetail", function () { return new WebPanePinnedEventArgsDetailDescription(); });
        a.ac("WebPanePinnedEventArgsDetail", WebPanePinnedEventArgsDetailDescriptionMetadata.a);
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.$t = markType(WebPanePinnedEventArgsDetailDescriptionMetadata, 'WebPanePinnedEventArgsDetailDescriptionMetadata');
    WebPanePinnedEventArgsDetailDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPanePinnedEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebPanePinnedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDetailDescription } from "./WebPanePinnedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPanePinnedEventArgsDetailDescriptionMetadata, _super);
    function WebPanePinnedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPanePinnedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPanePinnedEventArgsDetailDescriptionMetadata.a == null) {
            WebPanePinnedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPanePinnedEventArgsDetailDescriptionMetadata.c(WebPanePinnedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPanePinnedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPanePinnedEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PanePinnedEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SourcePane", "ExportedType:WebContentPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("NewValue", "Boolean");
        a.item("Location", "ExportedType:string:UnpinnedLocation");
        a.item("Location@stringUnion", "WebComponents;React");
        a.item("Location@names", "Top;Bottom;Left;Right");
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPanePinnedEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebPanePinnedEventArgsDetail", function () { return new WebPanePinnedEventArgsDetailDescription(); });
        a.ad("WebPanePinnedEventArgsDetail", WebPanePinnedEventArgsDetailDescriptionMetadata.a);
    };
    WebPanePinnedEventArgsDetailDescriptionMetadata.$t = markType(WebPanePinnedEventArgsDetailDescriptionMetadata, 'WebPanePinnedEventArgsDetailDescriptionMetadata');
    WebPanePinnedEventArgsDetailDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPanePinnedEventArgsDetailDescriptionMetadata };
